function View(_$root) {
    var self = this;
    var $root = _$root || {};
    var semester = {'Left': $('#semestersLeft'), 'Right': $('#semestersRight')};
    var group = {'Left': $('#groupLeft'), 'Right': $('#groupRight')};

    this.template = '<li id="%type%-%recordBookID%" class="TransferListItem">%studentName%</li>';

    // Эталонный костыль.
    this.adjustHeight = function (reset) {
        reset = typeof reset !== 'undefined' ? reset : false;
        var jTransferList = $("#TransferItemsList");
        var jRightList = $("#RightItemsList");

        // FIXME: No hardcode
        var HEIGHT = 661;
        if (!reset)
            jRightList.height(HEIGHT - jTransferList.height());
        else {
            jRightList.height(HEIGHT);
            jTransferList.height('auto');
        }
    };

    this.addToCounter = function (n) {
        var jCounter = $('.TransferCounter');
        var current = +jCounter.html();
        jCounter.html(current + n);
    };

    this.resetCounter = function () {
        var jCounter = $('.TransferCounter');
        jCounter.html('0');
    };

    this.clearList = function (type) {
        var jList = $root.find("#" + type + "ItemsList");
        jList.html('');
        if (type == 'Transfer')
            this.resetCounter();
    };

    this.fillList = function (type, students) {
        var jList = $root.find("#" + type + "ItemsList");
        this.clearList(type);
        students.forEach(function (elem) {
            var FullName = elem.LastName + ' ' + elem.FirstName + ' ' + elem.SecondName;
            var item = self.template.replace('%studentName%', FullName).replace('%recordBookID%', elem.recordBookID).replace('%type%', type);
            jList.append(item);
        });

        // показываем количество
        $root.find("#" + type + "ListAmount").text(students.length);
    };

    this.clearChecked = function (type, checkedStudents) {
        var jList = $root.find("#" + type + "ItemsList");
        checkedStudents.forEach(function (elem) {
            jList.find('li[id=' + type + '-' + elem.itemID + ']').remove();
        });
        this.addToCounter(-checkedStudents.length);
    };

    this.clearSelection = function (type, checkedStudents) {
        var jList = $root.find("#" + type + "ItemsList");
        checkedStudents.forEach(function (elem) {
            jList.find('li[id=' + type + '-' + elem.itemID + ']').removeClass('selected');
        });
    };

    this.addChecked = function (type, checkedStudents) {
        var jList = $root.find("#" + type + "ItemsList");
        var i = 0;
        checkedStudents.forEach(function (elem) {
            if (!$('#' + type + '-' + elem.itemID).length) {
                var item = self.template
                    .replace('%studentName%', elem.value)
                    .replace('%recordBookID%', elem.itemID)
                    .replace('%type%', type);
                jList.append(item);
                i++;
            }
        });
        this.addToCounter(+i);
    };

    // Обработчики событий
    var onAdditionToTransfer = function () {
        var from = 'Left';
        var to = 'Transfer';

        var jFrom = $root.find("#" + from + "ItemsList");

        // Создание массива из всех выбранных элементов, являющихся дочерними
        var listrecordBooksID = jFrom.find('li.selected').map(function () {
            return {'itemID': this.id.split('-')[1], 'value': $(this).html()};
        }).get();

        self.emit('addition', from, to, listrecordBooksID);
        self.adjustHeight();
    };

    var onAdditionAllToTransfer = function () {
        var from = 'Left';
        var to = 'Transfer';

        var jFrom = $root.find("#" + from + "ItemsList");

        // Создание массива из всех выбранных элементов, являющихся дочерними
        var listRecordBooksID = jFrom.find('li').map(function () {
            return {'itemID': this.id.split('-')[1], 'value': $(this).html()};
        }).get();

        self.emit('addition', from, to, listRecordBooksID);
        self.adjustHeight();
    };

    var onDeletionFromTransfer = function () {
        var from = 'Transfer';

        var jFrom = $root.find("#" + from + "ItemsList");

        // Создание массива из всех выбранных элементов, являющихся дочерними
        var listRecordBooksID = jFrom.find('li.selected').map(function () {
            return {'itemID': this.id.split('-')[1], 'value': $(this).html()};
        }).get();

        self.emit('deletion', from, listRecordBooksID);
        self.adjustHeight();
    };

    var onDeletionAllFromTransfer = function () {
        var from = 'Transfer';

        var jFrom = $root.find("#" + from + "ItemsList");

        // Создание массива из всех выбранных элементов, являющихся дочерними
        var listRecordBooksID = jFrom.find('li').map(function () {
            return {'itemID': this.id.split('-')[1], 'value': $(this).html()};
        }).get();

        self.emit('deletion', from, listRecordBooksID);
        self.adjustHeight(true);
    };

    var onTransfer = function () {
        var groupID = group.Right.val();
        var semesterID = +semester['Right'].val();

        self.emit('transfer', groupID, semesterID);
        if(groupID != -1)
            self.adjustHeight(true);
    };

    var onGroupSelect = function () {
        var id = $(this).attr('id');
        var res = /group(.*)/.exec(id);
        var type = res ? res[1] : '';
        var groupID = parseInt($(this).val());
        var semesterID = +semester[type].val();

        self.emit('groupLoad', type, groupID, semesterID);
        self.adjustHeight();
    };

    var onSemesterSelect = function () {
        var id = $(this).attr('id');
        var res = /semesters(.*)/.exec(id);
        var type = res ? res[1] : '';
        var semesterID = +$(this).val();
        var groupID = +group[type].val();

        self.emit('groupLoad', type, groupID, semesterID);
        self.adjustHeight();
    };

    // -----------------
    // Events (события)
    // -----------------

    // Обработка выбора группы
    group.Left.on('change', onGroupSelect);
    group.Right.on('change', onGroupSelect);
    semester.Left.on('change', onSemesterSelect);
    semester.Right.on('change', onSemesterSelect);
    // Обработка переноса по стрелкам
    $root.find('#addToTransferList').on('click', onAdditionToTransfer);
    $root.find('#addAllToTransferList').on('click', onAdditionAllToTransfer);
    $root.find('#deleteFromTransferList').on('click', onDeletionFromTransfer);
    $root.find('#deleteAllFromTransferList').on('click', onDeletionAllFromTransfer);
    // Подтверждение переноса
    $root.find('#transferApply').on('click', onTransfer);
    // Удаление студентов
    //$root.find('#studentDelete').on('click', onTransferRight);

}
View.prototype = Object.create(new EventEmitter());